==> haskell-servant-0.13.0.1-13-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-servant.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: servant
version: 0.13.0.1
id: servant-0.13.0.1-IQaOH1qUa2nAk7dOG59jNe
key: servant-0.13.0.1-IQaOH1qUa2nAk7dOG59jNe
license: BSD-3-Clause
copyright: 2014-2016 Zalora South East Asia Pte Ltd, Servant Contributors
maintainer: haskell-servant-maintainers@googlegroups.com
author: Servant Contributors
homepage: http://haskell-servant.readthedocs.org/
synopsis: A family of combinators for defining webservices APIs
description:
    A family of combinators for defining webservices APIs and serving them
    .
    You can learn about the basics in the <http://haskell-servant.readthedocs.org/en/stable/tutorial/index.html tutorial>.
    .
    <https://github.com/haskell-servant/servant/blob/master/servant/CHANGELOG.md CHANGELOG>
category: Servant, Web
abi: badacb15830e33f1bae4a9912d30b7c3
exposed: True
exposed-modules:
    Servant.API Servant.API.Alternative Servant.API.BasicAuth
    Servant.API.Capture Servant.API.ContentTypes
    Servant.API.Description Servant.API.Empty
    Servant.API.Experimental.Auth Servant.API.Header
    Servant.API.HttpVersion Servant.API.Internal.Test.ComprehensiveAPI
    Servant.API.IsSecure Servant.API.Modifiers Servant.API.QueryParam
    Servant.API.Raw Servant.API.RemoteHost Servant.API.ReqBody
    Servant.API.ResponseHeaders Servant.API.Stream Servant.API.Sub
    Servant.API.TypeLevel Servant.API.Vault Servant.API.Verbs
    Servant.API.WithNamedContext Servant.Utils.Enter
    Servant.Utils.Links
import-dirs: /usr/lib/ghc-8.4.3/site-local/servant-0.13.0.1
library-dirs: /usr/lib/ghc-8.4.3/site-local/servant-0.13.0.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/servant-0.13.0.1
hs-libraries: HSservant-0.13.0.1-IQaOH1qUa2nAk7dOG59jNe
depends:
    base-4.11.1.0 bytestring-0.10.8.2 mtl-2.2.2 text-1.2.3.0
    base-compat-0.10.1-LjQCAvvrOQx72iD1hHVjc6
    aeson-1.3.1.1-9XRC4e94J4n99AnBXEVUy1
    attoparsec-0.13.2.2-2rSZNTl4Hzq7SdjVOGnWBH
    case-insensitive-1.2.0.11-GjimmYhRn324HWbQThQUra
    http-api-data-0.3.8.1-K4emXiQFPXKFNpHjfZmlcf
    http-media-0.7.1.2-2agRPy8NKmR6zMh072NVzf
    http-types-0.12.1-AvwTvixVY2aCGvkbFE4VfX
    natural-transformation-0.4-H812UKihNmSBjnMSucJuXM
    mmorph-1.1.2-u5n0PR0ucK5U9RRLpSUlt
    tagged-0.8.5-8zhZJ4AR6AIK89q9NUJ4H
    singleton-bool-0.1.4-8EznQE6dMi2H7lit14Cx2C
    string-conversions-0.4.0.1-2odRrDeA1b0G507cZcdaLT
    network-uri-2.6.1.0-AstEwZoXrlUJQq4VkxaVo9
    vault-0.3.1.1-I1BsgFEfUrP7ZzNeEDleeu
abi-depends: base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
             bytestring-0.10.8.2=76943c00398d547fb172e56c2f93c635
             mtl-2.2.2=3cf3b316ad8e985e039ee3b498a98253
             text-1.2.3.0=be4c3e1c57cff1d501eb0e876706a48d
             base-compat-0.10.1-LjQCAvvrOQx72iD1hHVjc6=1d75d8a5e04e09d5efbd2d425663f665
             aeson-1.3.1.1-9XRC4e94J4n99AnBXEVUy1=35b49024653eeb9b79eed81b6925c2b9
             attoparsec-0.13.2.2-2rSZNTl4Hzq7SdjVOGnWBH=8e6e77bd73af6a8072fdc40742d8861e
             case-insensitive-1.2.0.11-GjimmYhRn324HWbQThQUra=bcd8ba72b672d042505b8fc55f637c88
             http-api-data-0.3.8.1-K4emXiQFPXKFNpHjfZmlcf=561a1e4fe1a6d306bbc311b23095b505
             http-media-0.7.1.2-2agRPy8NKmR6zMh072NVzf=3b8ff7a7eec0b45994664ca667110b69
             http-types-0.12.1-AvwTvixVY2aCGvkbFE4VfX=c36ea90c1caed733a7293143960ab603
             natural-transformation-0.4-H812UKihNmSBjnMSucJuXM=4bd55b0193d677b93b6dbf1f23bae4bb
             mmorph-1.1.2-u5n0PR0ucK5U9RRLpSUlt=c09e48de7c9591fe7d4e2ba81a9fcf9b
             tagged-0.8.5-8zhZJ4AR6AIK89q9NUJ4H=8f78e013407135fc5016173a57c7eb1b
             singleton-bool-0.1.4-8EznQE6dMi2H7lit14Cx2C=224d0377dd86bfef9c4c84d4841ba81f
             string-conversions-0.4.0.1-2odRrDeA1b0G507cZcdaLT=2754b46212c00717aaae8361f03806b5
             network-uri-2.6.1.0-AstEwZoXrlUJQq4VkxaVo9=1c5b19d707f7ce4714ffa81cd536dbf4
             vault-0.3.1.1-I1BsgFEfUrP7ZzNeEDleeu=c9da6017b26ba1d80e07a6a7ed88b617
haddock-interfaces: /usr/share/doc/haskell-servant/html/servant.haddock
haddock-html: /usr/share/doc/haskell-servant/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-servant-0.13.0.1-15-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-servant.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: servant
version: 0.13.0.1
id: servant-0.13.0.1-1eHtfqXLhwgEDz4I7414vh
key: servant-0.13.0.1-1eHtfqXLhwgEDz4I7414vh
license: BSD-3-Clause
copyright: 2014-2016 Zalora South East Asia Pte Ltd, Servant Contributors
maintainer: haskell-servant-maintainers@googlegroups.com
author: Servant Contributors
homepage: http://haskell-servant.readthedocs.org/
synopsis: A family of combinators for defining webservices APIs
description:
    A family of combinators for defining webservices APIs and serving them
    .
    You can learn about the basics in the <http://haskell-servant.readthedocs.org/en/stable/tutorial/index.html tutorial>.
    .
    <https://github.com/haskell-servant/servant/blob/master/servant/CHANGELOG.md CHANGELOG>
category: Servant, Web
abi: 17447d778ef7bc98d5b9ec4b4880235b
exposed: True
exposed-modules:
    Servant.API Servant.API.Alternative Servant.API.BasicAuth
    Servant.API.Capture Servant.API.ContentTypes
    Servant.API.Description Servant.API.Empty
    Servant.API.Experimental.Auth Servant.API.Header
    Servant.API.HttpVersion Servant.API.Internal.Test.ComprehensiveAPI
    Servant.API.IsSecure Servant.API.Modifiers Servant.API.QueryParam
    Servant.API.Raw Servant.API.RemoteHost Servant.API.ReqBody
    Servant.API.ResponseHeaders Servant.API.Stream Servant.API.Sub
    Servant.API.TypeLevel Servant.API.Vault Servant.API.Verbs
    Servant.API.WithNamedContext Servant.Utils.Enter
    Servant.Utils.Links
import-dirs: /usr/lib/ghc-8.4.3/site-local/servant-0.13.0.1
library-dirs: /usr/lib/ghc-8.4.3/site-local/servant-0.13.0.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/servant-0.13.0.1
hs-libraries: HSservant-0.13.0.1-1eHtfqXLhwgEDz4I7414vh
depends:
    base-4.11.1.0 bytestring-0.10.8.2 mtl-2.2.2 text-1.2.3.0
    base-compat-0.10.1-LjQCAvvrOQx72iD1hHVjc6
    aeson-1.3.1.1-J1bdggn8TZj5jjcHYxM7mi
    attoparsec-0.13.2.2-2rSZNTl4Hzq7SdjVOGnWBH
    case-insensitive-1.2.0.11-GjimmYhRn324HWbQThQUra
    http-api-data-0.3.8.1-LarLghTdl5uLYkRaF3jkC2
    http-media-0.7.1.2-2agRPy8NKmR6zMh072NVzf
    http-types-0.12.1-AvwTvixVY2aCGvkbFE4VfX
    natural-transformation-0.4-H812UKihNmSBjnMSucJuXM
    mmorph-1.1.2-u5n0PR0ucK5U9RRLpSUlt
    tagged-0.8.5-8zhZJ4AR6AIK89q9NUJ4H
    singleton-bool-0.1.4-8EznQE6dMi2H7lit14Cx2C
    string-conversions-0.4.0.1-2odRrDeA1b0G507cZcdaLT
    network-uri-2.6.1.0-AstEwZoXrlUJQq4VkxaVo9
    vault-0.3.1.1-I1BsgFEfUrP7ZzNeEDleeu
abi-depends: base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
             bytestring-0.10.8.2=76943c00398d547fb172e56c2f93c635
             mtl-2.2.2=3cf3b316ad8e985e039ee3b498a98253
             text-1.2.3.0=be4c3e1c57cff1d501eb0e876706a48d
             base-compat-0.10.1-LjQCAvvrOQx72iD1hHVjc6=1d75d8a5e04e09d5efbd2d425663f665
             aeson-1.3.1.1-J1bdggn8TZj5jjcHYxM7mi=4bd33a472ed49d1f25a046c18b4acb2d
             attoparsec-0.13.2.2-2rSZNTl4Hzq7SdjVOGnWBH=8e6e77bd73af6a8072fdc40742d8861e
             case-insensitive-1.2.0.11-GjimmYhRn324HWbQThQUra=bcd8ba72b672d042505b8fc55f637c88
             http-api-data-0.3.8.1-LarLghTdl5uLYkRaF3jkC2=ef2e3bf301f917bded966ae5a1d454b3
             http-media-0.7.1.2-2agRPy8NKmR6zMh072NVzf=3b8ff7a7eec0b45994664ca667110b69
             http-types-0.12.1-AvwTvixVY2aCGvkbFE4VfX=c36ea90c1caed733a7293143960ab603
             natural-transformation-0.4-H812UKihNmSBjnMSucJuXM=4bd55b0193d677b93b6dbf1f23bae4bb
             mmorph-1.1.2-u5n0PR0ucK5U9RRLpSUlt=c09e48de7c9591fe7d4e2ba81a9fcf9b
             tagged-0.8.5-8zhZJ4AR6AIK89q9NUJ4H=8f78e013407135fc5016173a57c7eb1b
             singleton-bool-0.1.4-8EznQE6dMi2H7lit14Cx2C=224d0377dd86bfef9c4c84d4841ba81f
             string-conversions-0.4.0.1-2odRrDeA1b0G507cZcdaLT=2754b46212c00717aaae8361f03806b5
             network-uri-2.6.1.0-AstEwZoXrlUJQq4VkxaVo9=1c5b19d707f7ce4714ffa81cd536dbf4
             vault-0.3.1.1-I1BsgFEfUrP7ZzNeEDleeu=c9da6017b26ba1d80e07a6a7ed88b617
haddock-interfaces: /usr/share/doc/haskell-servant/html/servant.haddock
haddock-html: /usr/share/doc/haskell-servant/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
